Page 53 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 53

Home

    took place. Here, Mlle Maillard, an opera singer,
    believed to be a prostitute, was crowned the "Goddess of

    At

    the

    address

    an

    was

    Reason and Virtue, should be substituted for the
    worship of the "Jewish slave" and "the adulterous
    woman, the courtesan of Galilee.""!

    The person who played the leading part in the
    campaign against religion was a Prussian baron named
    Anacharsis Clootz. He was a member of the Illuminati

    and had declared himself the personal enemy of Jesus
    Christ. Clootz wrote that, "Religion is a social disease
    which cannot be too quickly cured. A religious man is a
    depraved animal. . ae

    By intrigue, Clootz was able to get himself made a
    Representative of the Nation, and became a major
    influence in getting the government to sanction the

    Everywhere in France an orgy of blasphemy and
    desecration began. By order of the government,

    began.

    desecration began. By order of the government,
    inscriptions were put up in cemeteries all over France
    stating that, "Death is an eternal sleep." This was a
    cherished maxim of the Illuminati and, of course, an

    destroying the body, the regenerators of France set out to
    destroy the soul.

    48

    The Secret Side of History

    Reason."

    convention

    presented

    demanding that:

    antireligious movement.

    official denial of the Resurrection. Not content with